@@ -70,6 +70,10 @@
 ( cd opt/kde/share/doc/HTML/sv/kbounce ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdearch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdearch ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kbattleship ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kaboodle ; rm -rf common )
@@ -118,6 +122,8 @@
 ( cd opt/kde/share/doc/HTML/sv/ksame ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ksirc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/ksirc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/ktnef ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/ksysv ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ktron ; rm -rf common )
@@ -142,6 +148,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kmousetool ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kompare ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kontact ; rm -rf common )
@@ -174,6 +182,8 @@
 ( cd opt/kde/share/doc/HTML/sv/konquest ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kturtle ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kverbos ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kwallet ; rm -rf common )
@@ -192,8 +202,6 @@
 ( cd opt/kde/share/doc/HTML/sv/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kioslave ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/flashkard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/flashkard ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kaddressbook ; rm -rf common )
@@ -370,8 +378,6 @@
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/laptop ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kcontrol/kxmlrpcd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmnotify ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmsmserver ; rm -rf common )
@@ -456,6 +462,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kdevelop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kicker ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/klatin ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/klines ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kmines ; rm -rf common )
@@ -468,8 +476,6 @@
 ( cd opt/kde/share/doc/HTML/sv/knotes ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kpaint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kpaint ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kopete ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpilot ; rm -rf common )
@@ -510,8 +516,12 @@
 ( cd opt/kde/share/doc/HTML/sv/quanta ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kuickshow ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kolourpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kde_app_devel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kommander ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kommander ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kiconedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klettres ; rm -rf common )
@@ -524,12 +534,16 @@
 ( cd opt/kde/share/doc/HTML/sv/klickety ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kleopatra ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kenolaba ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kgpgcertmanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kworldclock ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/KRegExpEditor ; rm -rf common )
@@ -582,6 +596,8 @@
 ( cd opt/kde/share/doc/HTML/sv/umbrello ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konqueror ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/korganizer ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/atlantik ; rm -rf common )
